@@ -75,23 +75,34 @@ class WordPressAutoUpdater {
     /**
      * Get sites that have auto-updates enabled
      */
-    public function getSitesWithAutoUpdates($updateType = null, $siteId = null) {
+    public function getSitesWithAutoUpdates($requestedTypes = null, $siteId = null) {
         $conditions = ["status = 'active'"];
         $params = [];
-        
-        if ($updateType) {
-            switch ($updateType) {
-                case 'core':
-                    $conditions[] = "auto_update_core = 1";
-                    break;
-                case 'plugins':
-                    $conditions[] = "auto_update_plugins = 1";
-                    break;
-                case 'themes':
-                    $conditions[] = "auto_update_themes = 1";
-                    break;
-                default:
-                    throw new Exception("Invalid update type: {$updateType}");
+
+        // Normalize requestedTypes to array
+        if (is_string($requestedTypes)) {
+            $requestedTypes = [$requestedTypes];
+        }
+
+        if ($requestedTypes) {
+            $typeConditions = [];
+            foreach ($requestedTypes as $updateType) {
+                switch ($updateType) {
+                    case 'core':
+                        $typeConditions[] = "auto_update_core = 1";
+                        break;
+                    case 'plugins':
+                        $typeConditions[] = "auto_update_plugins = 1";
+                        break;
+                    case 'themes':
+                        $typeConditions[] = "auto_update_themes = 1";
+                        break;
+                    default:
+                        throw new Exception("Invalid update type: {$updateType}");
+                }
+            }
+            if (!empty($typeConditions)) {
+                $conditions[] = "(" . implode(' OR ', $typeConditions) . ")";
             }
         } else {
             $conditions[] = "(auto_update_core = 1 OR auto_update_plugins = 1 OR auto_update_themes = 1)";
@@ -110,21 +121,21 @@ class WordPressAutoUpdater {
     }
     
     /**
-     * Create backup before update
+     * Create backup before update and wait for completion
      */
-    private function createBackup($site) {
+    private function createAndWaitForBackup($site) {
         if (!$site['auto_backup_before_update']) {
             $this->log("Skipping backup for {$site['domain']} - auto backup disabled", 'INFO');
             return true;
         }
-        
+
         $this->log("Creating backup for {$site['domain']} before update", 'INFO');
-        
+
         if ($this->dryRun) {
-            $this->log("DRY RUN: Would create backup for site {$site['id']}", 'INFO');
+            $this->log("DRY RUN: Would create backup for site {$site['id']} and wait for completion", 'INFO');
             return true;
         }
-        
+
         try {
             // Create site backup using the backup engine with auto-update prefix
             $backupResult = $this->backupEngine->createWordPressBackup(
@@ -132,10 +143,20 @@ class WordPressAutoUpdater {
                 'auto_update_' . date('Y-m-d_H-i-s'), // Will be combined with domain in backup engine
                 $site['preferred_backup_target_id']
             );
-            
+
             if ($backupResult['success']) {
-                $this->log("Backup created successfully for {$site['domain']}: {$backupResult['backup_id']}", 'SUCCESS');
-                return true;
+                $backupId = $backupResult['backup_id'];
+                $this->log("Backup created successfully for {$site['domain']}: {$backupId}", 'SUCCESS');
+
+                // Wait for backup to complete
+                $this->log("Waiting for backup {$backupId} to complete before starting updates...", 'INFO');
+                if ($this->waitForBackupCompletion($backupId, $site['domain'])) {
+                    $this->log("Backup {$backupId} completed successfully, proceeding with updates", 'SUCCESS');
+                    return true;
+                } else {
+                    $this->log("Backup {$backupId} failed or timed out, aborting updates", 'ERROR');
+                    return false;
+                }
             } else {
                 $this->log("Backup failed for {$site['domain']}: " . $backupResult['error'], 'ERROR');
                 return false;
@@ -150,6 +171,59 @@ class WordPressAutoUpdater {
             return false;
         }
     }
+
+    /**
+     * Wait for backup to complete with timeout
+     */
+    private function waitForBackupCompletion($backupId, $domain, $maxWaitMinutes = 30) {
+        $maxWaitSeconds = $maxWaitMinutes * 60;
+        $checkInterval = 10; // Check every 10 seconds
+        $elapsed = 0;
+
+        $mysql = new mysqlmgmt();
+        $db = $mysql->getMySQLConnection();
+        $db->exec("USE whp");
+
+        while ($elapsed < $maxWaitSeconds) {
+            // Check backup status
+            $stmt = $db->prepare("SELECT status, error_message FROM backup_history WHERE id = ?");
+            $stmt->execute([$backupId]);
+            $backup = $stmt->fetch(PDO::FETCH_ASSOC);
+
+            if (!$backup) {
+                $this->log("Backup {$backupId} not found in database", 'ERROR');
+                return false;
+            }
+
+            switch ($backup['status']) {
+                case 'completed':
+                    return true;
+
+                case 'failed':
+                    $errorMsg = $backup['error_message'] ? ": " . $backup['error_message'] : "";
+                    $this->log("Backup {$backupId} failed{$errorMsg}", 'ERROR');
+                    return false;
+
+                case 'pending':
+                case 'claimed':
+                case 'running':
+                    // Still in progress, continue waiting
+                    $this->log("Backup {$backupId} status: {$backup['status']}, waiting... ({$elapsed}s elapsed)", 'INFO');
+                    break;
+
+                default:
+                    $this->log("Backup {$backupId} has unknown status: {$backup['status']}", 'WARNING');
+                    break;
+            }
+
+            sleep($checkInterval);
+            $elapsed += $checkInterval;
+        }
+
+        // Timeout reached
+        $this->log("Backup {$backupId} timed out after {$maxWaitMinutes} minutes", 'ERROR');
+        return false;
+    }
     
     /**
      * Update WordPress core
@@ -301,23 +375,57 @@ class WordPressAutoUpdater {
     /**
      * Process updates for a single site
      * @param array $site The site data
-     * @param string|null $updateType Specific update type to run (core|plugins|themes), or null for all
+     * @param array|string|null $requestedTypes Specific update types to run, or null for all
      */
-    public function processSite($site, $updateType = null) {
+    public function processSite($site, $requestedTypes = null) {
         $this->log("Processing site: {$site['domain']} (ID: {$site['id']})", 'INFO');
 
-        $success = true;
+        // Normalize requestedTypes to array
+        if (is_string($requestedTypes)) {
+            $requestedTypes = [$requestedTypes];
+        }
 
-        // Create backup if needed
-        if (!$this->createBackup($site)) {
+        // Determine which updates will actually run
+        $updatesToRun = [];
+        if ($requestedTypes) {
+            // Specific update types requested
+            foreach ($requestedTypes as $type) {
+                switch ($type) {
+                    case 'core':
+                        if ($site['auto_update_core']) $updatesToRun[] = 'core';
+                        break;
+                    case 'plugins':
+                        if ($site['auto_update_plugins']) $updatesToRun[] = 'plugins';
+                        break;
+                    case 'themes':
+                        if ($site['auto_update_themes']) $updatesToRun[] = 'themes';
+                        break;
+                }
+            }
+        } else {
+            // All enabled update types
+            if ($site['auto_update_core']) $updatesToRun[] = 'core';
+            if ($site['auto_update_plugins']) $updatesToRun[] = 'plugins';
+            if ($site['auto_update_themes']) $updatesToRun[] = 'themes';
+        }
+
+        if (empty($updatesToRun)) {
+            $this->log("No updates enabled for {$site['domain']}, skipping", 'INFO');
+            return true;
+        }
+
+        $this->log("Updates to run for {$site['domain']}: " . implode(', ', $updatesToRun), 'INFO');
+
+        // Create backup ONCE and wait for completion before ANY updates
+        if (!$this->createAndWaitForBackup($site)) {
             $this->log("Skipping updates for {$site['domain']} due to backup failure", 'ERROR');
             return false;
         }
 
-        // If a specific update type is specified, only run that type
-        // Otherwise, run all enabled update types for the site
-        if ($updateType) {
-            switch ($updateType) {
+        // Now run all the updates
+        $success = true;
+        foreach ($updatesToRun as $type) {
+            switch ($type) {
                 case 'core':
                     if (!$this->updateCore($site)) {
                         $success = false;
@@ -334,22 +442,6 @@ class WordPressAutoUpdater {
                     }
                     break;
             }
-        } else {
-            // Run all update types that are enabled for the site
-            // Update core
-            if (!$this->updateCore($site)) {
-                $success = false;
-            }
-
-            // Update plugins
-            if (!$this->updatePlugins($site)) {
-                $success = false;
-            }
-
-            // Update themes
-            if (!$this->updateThemes($site)) {
-                $success = false;
-            }
         }
 
         if ($success) {
@@ -364,8 +456,8 @@ class WordPressAutoUpdater {
     /**
      * Run auto-updates for all eligible sites
      */
-    public function runAutoUpdates($updateType = null, $siteId = null) {
-        $sites = $this->getSitesWithAutoUpdates($updateType, $siteId);
+    public function runAutoUpdates($requestedTypes = null, $siteId = null) {
+        $sites = $this->getSitesWithAutoUpdates($requestedTypes, $siteId);
         
         if (empty($sites)) {
             $this->log("No sites found with auto-updates enabled", 'INFO');
@@ -378,7 +470,7 @@ class WordPressAutoUpdater {
         $failureCount = 0;
         
         foreach ($sites as $site) {
-            if ($this->processSite($site, $updateType)) {
+            if ($this->processSite($site, $requestedTypes)) {
                 $successCount++;
             } else {
                 $failureCount++;
@@ -398,17 +490,56 @@ class WordPressAutoUpdater {
 $options = getopt('', ['dry-run', 'site-id:', 'type:']);
 $dryRun = isset($options['dry-run']);
 $siteId = $options['site-id'] ?? null;
-$updateType = $options['type'] ?? null;
+$updateTypes = $options['type'] ?? null;
 
-// Validate update type
-if ($updateType && !in_array($updateType, ['core', 'plugins', 'themes'])) {
-    echo "Error: Invalid update type. Must be one of: core, plugins, themes\n";
-    exit(1);
+// Parse and validate update types
+$validTypes = ['core', 'plugins', 'themes'];
+$requestedTypes = [];
+
+if ($updateTypes) {
+    // Split comma-separated types
+    $typeList = array_map('trim', explode(',', $updateTypes));
+
+    // Validate each type
+    foreach ($typeList as $type) {
+        if (!in_array($type, $validTypes)) {
+            echo "Error: Invalid update type '$type'. Must be one of: " . implode(', ', $validTypes) . "\n";
+            echo "Usage: php wordpress-auto-update.php [--dry-run] [--site-id=ID] [--type=TYPE1,TYPE2,...]\n";
+            echo "\n";
+            echo "Examples:\n";
+            echo "  php wordpress-auto-update.php                          # Run all enabled updates for all sites\n";
+            echo "  php wordpress-auto-update.php --type=core              # Run only core updates\n";
+            echo "  php wordpress-auto-update.php --type=core,plugins      # Run core and plugin updates\n";
+            echo "  php wordpress-auto-update.php --type=plugins,themes    # Run plugin and theme updates\n";
+            echo "  php wordpress-auto-update.php --site-id=123            # Run updates for specific site\n";
+            echo "  php wordpress-auto-update.php --site-id=123 --type=core,plugins  # Specific site, core+plugins only\n";
+            echo "  php wordpress-auto-update.php --dry-run                # Show what would be done without executing\n";
+            exit(1);
+        }
+    }
+
+    // Remove duplicates and sort
+    $requestedTypes = array_unique($typeList);
+    sort($requestedTypes);
 }
 
 try {
     $updater = new WordPressAutoUpdater($dryRun);
-    $updater->runAutoUpdates($updateType, $siteId);
+
+    // Log what types were requested
+    if ($requestedTypes) {
+        echo "Running WordPress auto-updates for types: " . implode(', ', $requestedTypes) . "\n";
+    } else {
+        echo "Running WordPress auto-updates for all enabled types\n";
+    }
+
+    if ($siteId) {
+        echo "Limiting to site ID: $siteId\n";
+    }
+
+    echo "\n";
+
+    $updater->runAutoUpdates($requestedTypes, $siteId);
 } catch (Exception $e) {
     echo "Fatal error: " . $e->getMessage() . "\n";
     exit(1);
