@@ -161,9 +161,9 @@ docker pull repo.anhonesthost.net/cloud-hosting-platform/haproxy-manager-base:la
 docker pull mariadb:10.11
 # Generate root MySQL Password
 mysql_password=$(tr -dc 'A-Za-z0-9!?&()-+=' </dev/urandom | head -c 18)
-# Start MariaDB
-docker run -d --network client-net --name mysql --env MARIADB_ROOT_PASSWORD="$mysql_password" -v /docker/mysql:/var/lib/mysql:Z  -p 3306:3306 --restart unless-stopped mariadb:10.11
-# Store mysql login details
+# Start MariaDB (bind to localhost for host access, accessible via container name within Docker network)
+docker run -d --network client-net --name mysql --env MARIADB_ROOT_PASSWORD="$mysql_password" -v /docker/mysql:/var/lib/mysql:Z -p 127.0.0.1:3306:3306 --restart unless-stopped mariadb:10.11
+# Store mysql login details (use localhost for host-based connections)
 echo "[client]" > /root/.my.cnf
 echo "host=127.0.0.1" >> /root/.my.cnf
 echo "user=root" >> /root/.my.cnf
@@ -175,9 +175,9 @@ docker pull postgres:latest
 postgres_password=$(tr -dc 'A-Za-z0-9!?&()-+=' </dev/urandom | head -c 18)
 # Create PostgreSQL data directory
 mkdir -p /docker/postgresql
-# Start PostgreSQL
-docker run -d --network client-net --name postgresql --env POSTGRES_PASSWORD="$postgres_password" -v /docker/postgresql:/var/lib/postgresql/data:Z -p 5432:5432 --restart unless-stopped postgres:latest
-# Store PostgreSQL login details in .pgpass format
+# Start PostgreSQL (bind to localhost for host access, accessible via container name within Docker network)
+docker run -d --network client-net --name postgresql --env POSTGRES_PASSWORD="$postgres_password" -v /docker/postgresql:/var/lib/postgresql/data:Z -p 127.0.0.1:5432:5432 --restart unless-stopped postgres:latest
+# Store PostgreSQL login details in .pgpass format (use localhost for host-based connections)
 echo "127.0.0.1:5432:*:postgres:$postgres_password" > /root/.pgpass
 chmod 600 /root/.pgpass
 
