@@ -423,6 +423,22 @@ class BackupEngine {
     }
     
     private function triggerBackgroundProcessing() {
+        // Use a lock file to prevent multiple worker instances
+        $lockFile = '/tmp/backup-worker.lock';
+
+        // Check if a worker is already running
+        if (file_exists($lockFile)) {
+            $pid = trim(file_get_contents($lockFile));
+            // Check if the process is actually running
+            if ($pid && posix_kill($pid, 0)) {
+                // Worker is still running, don't start another
+                return;
+            } else {
+                // Stale lock file, remove it
+                unlink($lockFile);
+            }
+        }
+
         // Trigger background processing asynchronously
         $scriptPath = dirname(__DIR__) . '/scripts/backup-worker.php';
         if (file_exists($scriptPath)) {
