@@ -305,33 +305,56 @@ class WordPressManager {
     
     /**
      * Update WordPress core
+     * @param int $siteId Site ID
+     * @param bool $createBackup Whether to create backup before update
+     * @return array Result array
      */
-    public function updateCore($siteId) {
+    public function updateCore($siteId, $createBackup = null) {
         $site = $this->getSite($siteId);
         if (!$site) {
             throw new Exception("Site not found");
         }
-        
+
+        // If createBackup is not specified, use site's auto_backup_before_update setting
+        if ($createBackup === null) {
+            $createBackup = $site['auto_backup_before_update'] ?? false;
+        }
+
         // Record update start
         $updateId = $this->recordUpdateStart($siteId, 'core', 'WordPress Core', $site['wp_version']);
-        
+
         try {
-            // Perform the update directly
-            $result = $this->performCoreUpdateBackground($siteId, $updateId);
-            
-            return [
-                'success' => true, 
-                'message' => 'WordPress core update completed successfully',
-                'update_id' => $updateId,
-                'status' => 'completed',
-                'new_version' => $result['new_version'] ?? null,
-                'backup_results' => $result['backup_results'] ?? null
-            ];
-            
+            if ($createBackup) {
+                // Queue backup first, then queue update to wait for backup completion
+                $result = $this->queueUpdateWithBackup($siteId, $updateId, 'core');
+
+                return [
+                    'success' => true,
+                    'message' => 'WordPress core update and backup queued successfully',
+                    'update_id' => $updateId,
+                    'status' => 'queued',
+                    'backup_id' => $result['backup_id'] ?? null,
+                    'queue_mode' => true
+                ];
+            } else {
+                // Perform immediate update without backup
+                $result = $this->performCoreUpdateImmediate($siteId, $updateId);
+
+                return [
+                    'success' => true,
+                    'message' => 'WordPress core update completed successfully',
+                    'update_id' => $updateId,
+                    'status' => 'completed',
+                    'new_version' => $result['new_version'] ?? null,
+                    'backup_results' => $result['backup_results'] ?? null,
+                    'queue_mode' => false
+                ];
+            }
+
         } catch (Exception $e) {
             // Record failure
             $this->recordUpdateFailed($updateId, $e->getMessage());
-            
+
             return [
                 'success' => false,
                 'message' => 'WordPress core update failed: ' . $e->getMessage(),
@@ -344,33 +367,54 @@ class WordPressManager {
     /**
      * Update WordPress core, plugins, and themes
      * @param int $siteId Site ID
+     * @param bool $createBackup Whether to create backup before update
      * @return array Result array
      */
-    public function updateAll($siteId) {
+    public function updateAll($siteId, $createBackup = null) {
         $site = $this->getSite($siteId);
         if (!$site) {
             throw new Exception("Site not found");
         }
-        
+
+        // If createBackup is not specified, use site's auto_backup_before_update setting
+        if ($createBackup === null) {
+            $createBackup = $site['auto_backup_before_update'] ?? false;
+        }
+
         // Record update start for comprehensive update
         $updateId = $this->recordUpdateStart($siteId, 'all', 'WordPress Complete Update', $site['wp_version']);
-        
+
         try {
-            // Perform the comprehensive update
-            $result = $this->performCompleteUpdateBackground($siteId, $updateId);
-            
-            return [
-                'success' => true, 
-                'message' => 'WordPress complete update finished successfully',
-                'update_id' => $updateId,
-                'status' => 'completed',
-                'results' => $result
-            ];
-            
+            if ($createBackup) {
+                // Queue backup first, then queue update to wait for backup completion
+                $result = $this->queueUpdateWithBackup($siteId, $updateId, 'all');
+
+                return [
+                    'success' => true,
+                    'message' => 'WordPress update and backup queued successfully',
+                    'update_id' => $updateId,
+                    'status' => 'queued',
+                    'backup_id' => $result['backup_id'] ?? null,
+                    'queue_mode' => true
+                ];
+            } else {
+                // Perform immediate update without backup
+                $result = $this->performCompleteUpdateImmediate($siteId, $updateId);
+
+                return [
+                    'success' => true,
+                    'message' => 'WordPress complete update finished successfully',
+                    'update_id' => $updateId,
+                    'status' => 'completed',
+                    'results' => $result,
+                    'queue_mode' => false
+                ];
+            }
+
         } catch (Exception $e) {
             // Record failure
             $this->recordUpdateFailed($updateId, $e->getMessage());
-            
+
             return [
                 'success' => false,
                 'message' => 'WordPress complete update failed: ' . $e->getMessage(),
@@ -381,14 +425,14 @@ class WordPressManager {
     }
     
     /**
-     * Perform comprehensive WordPress update (core, plugins, themes) in background
+     * Perform comprehensive WordPress update (core, plugins, themes) immediately without backup
      */
-    public function performCompleteUpdateBackground($siteId, $updateId) {
+    public function performCompleteUpdateImmediate($siteId, $updateId) {
         $site = $this->getSite($siteId);
         if (!$site) {
             throw new Exception("Site not found");
         }
-        
+
         $container = $site['domain'] . '-01';
         $user = $site['user'];
         $results = [
@@ -397,18 +441,9 @@ class WordPressManager {
             'themes' => null,
             'backup_results' => null
         ];
-        
-        // Create backup first
-        if ($site['backup_target_id'] || $site['preferred_backup_target_id']) {
-            try {
-                $backupResult = $this->createBackup($site);
-                $results['backup_results'] = $backupResult;
-                // Backup created successfully
-            } catch (Exception $e) {
-                // Backup failed: continuing with update
-                // Continue with update even if backup fails
-            }
-        }
+
+        // No backup - this is an immediate update
+        error_log("WordPress Update: Starting immediate update for site {$siteId} (no backup)");
         
         // Update WordPress core
         try {
@@ -474,28 +509,17 @@ class WordPressManager {
     }
     
     /**
-     * Perform WordPress core update in background
+     * Perform WordPress core update immediately without backup
      */
-    public function performCoreUpdateBackground($siteId, $updateId) {
+    public function performCoreUpdateImmediate($siteId, $updateId) {
         $site = $this->getSite($siteId);
         if (!$site) {
             throw new Exception("Site not found");
         }
         
+        // No backup - this is an immediate update
         $backupResults = [];
-        
-        // Create backup if enabled
-        if ($site['auto_backup_before_update']) {
-            try {
-                $backupResults = $this->createBackup($site, 'pre-update');
-                error_log("WordPress Update: Backup created for site {$siteId}");
-            } catch (Exception $e) {
-                // Log the error but continue with update
-                error_log("WordPress Update: Failed to create backup: " . $e->getMessage());
-                // For critical sites, you might want to stop here:
-                // throw new Exception("Failed to create pre-update backup: " . $e->getMessage());
-            }
-        }
+        error_log("WordPress Update: Starting immediate core update for site {$siteId} (no backup)");
         
         try {
             // Update WordPress core
@@ -2077,4 +2101,90 @@ Options -Indexes
         
         return true;
     }
+
+    /**
+     * Queue backup and update together (backup first, then update waits for completion)
+     */
+    private function queueUpdateWithBackup($siteId, $updateId, $updateType) {
+        $site = $this->getSite($siteId);
+        if (!$site) {
+            throw new Exception("Site not found");
+        }
+
+        error_log("WordPress Update: Queuing backup + update for site {$siteId}, update type: {$updateType}");
+
+        // Create the combined WordPress backup using BackupEngine (queued for background processing)
+        $backupData = $this->backupEngine->createWordPressBackup(
+            $site['user'],
+            $site['domain'],
+            $site['preferred_backup_target_id'] ?? null
+        );
+
+        if (!$backupData || !isset($backupData['backup_id'])) {
+            throw new Exception("Failed to queue WordPress backup");
+        }
+
+        $backupId = $backupData['backup_id'];
+        error_log("WordPress Update: Queued backup ID {$backupId}");
+
+        // Queue the update to run after backup completes
+        $this->queueWordPressUpdate($siteId, $updateId, $updateType, $backupId);
+
+        return [
+            'success' => true,
+            'backup_id' => $backupId,
+            'backup_name' => $backupData['backup_name'] ?? null,
+            'update_id' => $updateId,
+            'status' => 'queued',
+            'message' => 'Backup and update queued for background processing'
+        ];
+    }
+
+    /**
+     * Queue WordPress update to run after backup completion
+     */
+    private function queueWordPressUpdate($siteId, $updateId, $updateType, $backupId) {
+        // Add to wp_update_queue table to be processed by background worker
+        $stmt = $this->db->prepare("
+            INSERT INTO wp_update_queue
+            (site_id, update_id, update_type, backup_id, status, created_at)
+            VALUES (?, ?, ?, ?, 'waiting_for_backup', NOW())
+        ");
+
+        $stmt->execute([$siteId, $updateId, $updateType, $backupId]);
+        $queueId = $this->db->lastInsertId();
+
+        error_log("WordPress Update: Queued update ID {$updateId} (type: {$updateType}) to wait for backup {$backupId}, queue ID: {$queueId}");
+
+        return $queueId;
+    }
+
+    /**
+     * Create WordPress backup using the new combined backup system (background only)
+     */
+    private function createWordPressBackupForUpdate($site) {
+        error_log("WordPress Update: Queuing combined WordPress backup for site {$site['domain']}");
+
+        // Create the combined WordPress backup using BackupEngine (returns immediately)
+        $backupData = $this->backupEngine->createWordPressBackup(
+            $site['user'],
+            $site['domain'],
+            $site['preferred_backup_target_id'] ?? null
+        );
+
+        if (!$backupData || !isset($backupData['backup_id'])) {
+            throw new Exception("Failed to queue WordPress backup");
+        }
+
+        $backupId = $backupData['backup_id'];
+        error_log("WordPress Update: Queued backup ID {$backupId} for background processing");
+
+        return [
+            'success' => true,
+            'backup_id' => $backupId,
+            'backup_name' => $backupData['backup_name'] ?? null,
+            'status' => 'queued',
+            'message' => 'Backup queued for background processing'
+        ];
+    }
 }
\ No newline at end of file
